# -*- coding: cp1252 -*-
import wx
import os
from xml.dom import minidom
import base64


class MyApp(wx.App):
    def OnInit(self):
        self.readConfig()

        frame = wx.Frame(None, -1, self.xml_apptitle+" ("+str(len(self.liste))+")", size=(610,400), style=wx.DEFAULT_FRAME_STYLE & ~ (wx.RESIZE_BORDER | wx.RESIZE_BOX | wx.MAXIMIZE_BOX))
        frame.SetAutoLayout(True)
        frame.SetBackgroundColour("LIGHTGREY")


        sampleList=[]
        for item in self.liste:
            sampleList.append(item["name"])
        
        lc = wx.LayoutConstraints()
        lc.top.SameAs(frame, wx.Top, 1)
        lc.left.SameAs(frame, wx.Left, 1)
        lc.bottom.SameAs(frame, wx.Bottom, 1)
        lc.right.SameAs(frame, wx.Left, -240)
        
        self.lb1 = wx.ListBox(frame, 60, (0, 0), (10, 100), sampleList, wx.LB_SINGLE)
        self.lb1.SetConstraints(lc)

        self.Bind(wx.EVT_LISTBOX, self.EvtListBox, self.lb1)
        self.Bind(wx.EVT_LISTBOX_DCLICK, self.EvtListBoxDClick, self.lb1)

        self.b1 = wx.Button(frame, 10, self.xml_run_button_label, (20, 20))
        self.b1.Bind(wx.EVT_BUTTON, self.runGame, self.b1)
        lc = wx.LayoutConstraints()
        lc.top.SameAs(frame, wx.Bottom, -40)
        lc.left.SameAs(frame, wx.Left, 260)
        lc.bottom.SameAs(frame, wx.Bottom, 10)
        lc.right.SameAs(frame, wx.Right, 20)
        self.b1.SetConstraints(lc)

        self.b2 = wx.Button(frame, 10, self.xml_link_button_label, (20, 20))
        self.b2.Bind(wx.EVT_BUTTON, self.makeLNK, self.b2)
        lc = wx.LayoutConstraints()
        lc.top.SameAs(frame, wx.Bottom, -65)
        lc.left.SameAs(frame, wx.Left, 260)
        lc.bottom.SameAs(frame, wx.Bottom, 45)
        lc.right.SameAs(frame, wx.Right, 20)
        self.b2.SetConstraints(lc)

        self.b3 = wx.Button(frame, 10, self.xml_doc_button_label, (20, 20))
        self.b3.Bind(wx.EVT_BUTTON, self.ShowDocs, self.b3)
        lc = wx.LayoutConstraints()
        lc.top.SameAs(frame, wx.Bottom, -90)
        lc.left.SameAs(frame, wx.Left, 260)
        lc.bottom.SameAs(frame, wx.Bottom, 70)
        lc.right.SameAs(frame, wx.Right, 20)
        self.b3.SetConstraints(lc)
        
        self.l1 = wx.StaticText(frame, -1, "")
        lc = wx.LayoutConstraints()
        lc.top.SameAs(frame, wx.Top, 2)
        lc.left.SameAs(frame, wx.Left, 260)
        lc.bottom.SameAs(frame, wx.Top, -18)
        lc.right.SameAs(frame, wx.Right, 20)
        self.l1.SetConstraints(lc)

        font = wx.Font(10, wx.SWISS, wx.NORMAL, wx.BOLD)
        self.l1.SetFont(font)
        
        jpg = self.loadImage("") 
        self.screenshot=wx.StaticBitmap(frame, -1, jpg, (260, 20), (320, 240))
        
        frame.Show(True)
        self.SetTopWindow(frame)
        self.frame=frame

        self.lb1.SetSelection(0)
        self.changePage(0)

        if os.path.exists("icon.ico"):
            icon1 = wx.Icon("icon.ico", wx.BITMAP_TYPE_ICO)
            frame.SetIcon(icon1)
        
        return True



    def makeLNK(self,event):
        cmd=self.liste[self.lb1.GetSelections()[0]]['cmd']
        name=self.liste[self.lb1.GetSelections()[0]]['name']
        icon=self.liste[self.lb1.GetSelections()[0]]['icon']
        tmp=cmd.split()
        cmd=tmp[0]
        args=""
        for x in tmp[1:len(tmp)]:
            args=args+" "+x
        
        if cmd:
           os.system('start makeLNK.vbs "'+name+'" "'+cmd+'" "'+args+'" "'+icon+'"')
        return

    def ShowDocs(self,event):
        cmd=self.liste[self.lb1.GetSelections()[0]]['docpath']
        if cmd:
           os.system("explorer.exe "+os.getcwd()+"\\"+cmd)
        return

    def runGame(self, event):
        cmd=self.liste[self.lb1.GetSelections()[0]]['cmd']
        if cmd:
           cmd=cmd.split()
           os.execv(cmd[0],cmd)
        return

    def EvtListBox(self, event):
        self.changePage(event.GetSelection())
        return

    def changePage(self, i):
        name=self.liste[i]["name"]
        self.l1.SetLabel(name)
        p=self.liste[i]["image"]

        self.screenshot.SetBitmap(self.loadImage(p))
        
        self.b3.Disable()
        if self.liste[i]["docpath"]:
            self.b3.Enable()      
        return
        

    def EvtListBoxDClick(self, event):
        self.changePage(event.GetSelection())
        self.runGame(event)
        return



    def Fehlermeldung(self, text):
        dlg = wx.MessageDialog(None, text,'Fehler',wx.OK | wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()
        exit()


    def loadImage(self, name):
        path=self.xml_imagepath+"no_image.jpg"
        if name:
            path=self.xml_imagepath+name
        try:
            jpg = wx.Image(path, wx.BITMAP_TYPE_JPEG).ConvertToBitmap()
        except Exception, e:
            self.Fehlermeldung("Image "+path+" not found!\n"+str(e))
            
        if not (jpg.GetHeight()==240 and jpg.GetWidth()==320):
            jpg=wx.Image(path, wx.BITMAP_TYPE_JPEG).Scale(320, 240, quality=wx.IMAGE_QUALITY_NORMAL).ConvertToBitmap()
        return jpg
        

        
    def readConfig(self):
        try:
            xmldoc = minidom.parse('data.xml')
        except Exception, e:
            self.Fehlermeldung("Error in file data.xml.\n"+str(e))

        #Pfad zu Bildern
        self.xml_imagepath=""
        l=xmldoc.getElementsByTagName('imagepath')
        if l:
            self.xml_imagepath=l[0].firstChild.data

        #Pfad zu Icons
        self.xml_iconpath=""
        l=xmldoc.getElementsByTagName('iconpath')
        if l:
            self.xml_iconpath=l[0].firstChild.data
        
        #Titel der Applikation
        self.xml_apptitle="Launcher"
        l=xmldoc.getElementsByTagName('apptitle')
        if l:
            self.xml_apptitle=l[0].firstChild.data

        #Buttonlabels
        self.xml_run_button_label="run"
        l=xmldoc.getElementsByTagName('button_run')
        if l:
            self.xml_run_button_label=l[0].firstChild.data
        
        self.xml_link_button_label="Create Shortcut on Desktop"
        l=xmldoc.getElementsByTagName('button_link')
        if l:
            self.xml_link_button_label=l[0].firstChild.data
            
        self.xml_doc_button_label="Documentation"
        l=xmldoc.getElementsByTagName('button_doc')
        if l:
            self.xml_doc_button_label=l[0].firstChild.data


        
        # Listenelemente einlesen      
        l=xmldoc.getElementsByTagName('item')
        liste=[]


        for item in l:
            tmpliste={}
            tmpliste["name"]=''
            tmpliste["cmd"]=''
            tmpliste["docpath"]=''
            tmpliste["image"]=''
            tmpliste["icon"]='icon.ico'
            
            t=item.getElementsByTagName('name')
            if t:
                tmpliste["name"]=t[0].firstChild.data
               
            t=item.getElementsByTagName('cmd')
            if t:
                tmpliste["cmd"]=t[0].firstChild.data

            t=item.getElementsByTagName('docpath')
            if t:
                tmpliste["docpath"]=t[0].firstChild.data

            t=item.getElementsByTagName('image')
            if t:
                tmpliste["image"]=t[0].firstChild.data
                
            t=item.getElementsByTagName('icon')
            if t:
                tmpliste["icon"]=self.xml_iconpath+t[0].firstChild.data
                

            if not tmpliste["name"]=='':
                liste.append(tmpliste)

        if len(liste)==0:
            self.Fehlermeldung("Empty Itemlist.")

        #sortieren
        namen=[]
        for item in liste:
            namen.append(item["name"])
        namen.sort()
        
        neueliste=[]
        for item in namen:
            for item2 in liste:
                if item2["name"]==item:
                    neueliste.append(item2)
                    break
        self.liste=neueliste

app = MyApp(0)
app.MainLoop()

